'use client'

import React, { useState } from 'react'
import { motion, AnimatePresence } from 'framer-motion'
import { Plus, Minus } from 'lucide-react'

interface FAQItemProps {
  question: string
  answer: string
}

const faqItems: FAQItemProps[] = [
  {
    question: "What is a hero section and how does a hero section benefit my website?",
    answer: "A hero section is the first thing visitors see when they land on your website. It typically includes a headline, subheadline, and a call-to-action. It benefits your website by making a strong first impression, clearly communicating your value proposition, and guiding visitors to take action."
  },
  {
    question: "Can I use Slider Revolution to make a landing page with a hero section?",
    answer: "Yes, Slider Revolution is an excellent tool for creating dynamic and engaging hero sections for landing pages. It offers a wide range of customization options, animations, and responsive designs that can help you create an impactful hero section that captures visitors' attention and drives conversions."
  }
]

const FAQItem: React.FC<FAQItemProps> = ({ question, answer }) => {
  const [isOpen, setIsOpen] = useState(false)

  return (
    <motion.div 
      className="fqs-faq-item bg-white rounded-lg shadow-md overflow-hidden"
      initial={{ opacity: 0, y: 20 }}
      whileInView={{ opacity: 1, y: 0 }}
      viewport={{ once: true }}
      transition={{ duration: 0.5 }}
    >
      <motion.button
        className="fqs-faq-question w-full text-left px-6 py-4 flex justify-between items-center focus:outline-none focus:ring-2 focus:ring-blue-500"
        onClick={() => setIsOpen(!isOpen)}
        whileHover={{ backgroundColor: "#f0f0f0" }}
        whileTap={{ scale: 0.98 }}
      >
        <span className="fqs-question-text font-semibold">{question}</span>
        {isOpen ? <Minus className="fqs-icon" /> : <Plus className="fqs-icon" />}
      </motion.button>
      <AnimatePresence>
        {isOpen && (
          <motion.div
            className="fqs-faq-answer px-6 py-4 bg-gray-50"
            initial={{ opacity: 0, height: 0 }}
            animate={{ opacity: 1, height: "auto" }}
            exit={{ opacity: 0, height: 0 }}
            transition={{ duration: 0.3 }}
          >
            <p>{answer}</p>
          </motion.div>
        )}
      </AnimatePresence>
    </motion.div>
  )
}

const FAQSection: React.FC = () => {
  return (
    <section className="fqs-section py-16 px-4" style={{ background: "url('/faq-background.png')" }}>
      <div className="fqs-container max-w-4xl mx-auto">
        <motion.h2 
          className="fqs-title text-4xl font-bold text-center mb-4"
          initial={{ opacity: 0, y: -20 }}
          whileInView={{ opacity: 1, y: 0 }}
          viewport={{ once: true }}
          transition={{ duration: 0.5 }}
        >
          Frequently Asked Questions
        </motion.h2>
        <motion.p 
          className="fqs-subtitle text-center text-gray-600 mb-12"
          initial={{ opacity: 0, y: -20 }}
          whileInView={{ opacity: 1, y: 0 }}
          viewport={{ once: true }}
          transition={{ duration: 0.5, delay: 0.2 }}
        >
          Browse answers to common questions about our services and products.
        </motion.p>
        <div className="fqs-faq-list space-y-4">
          {faqItems.map((item, index) => (
            <FAQItem key={index} {...item} />
          ))}
        </div>
      </div>
    </section>
  )
}

export default FAQSection